from decimal import Decimal as D

from oscar.apps.shipping.methods import Free, FixedPrice
from oscar.apps.shipping.repository import Repository as CoreRepository


class Repository(CoreRepository):
    """
    This class is included so that there is a choice of shipping methods.
    Oscar's default behaviour is to only have one which means you can't test the
    shipping features of PayPal.
    """

    def get_shipping_methods(self, user, basket, shipping_addr=None, **kwargs):
        methods = [Free(), FixedPrice(D('10.00')), FixedPrice(D('20.00'))]
        return self.add_basket_to_methods(basket, methods)



from django.conf.urls.defaults import *
from django.conf import settings
from django.contrib import admin
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.conf.urls.static import static
from django.views.generic import TemplateView

from oscar.app import shop

admin.autodiscover()

urlpatterns = patterns('',
    (r'^admin/', include(admin.site.urls)),
    # Include the below line to enable PayPal integration
    (r'^checkout/paypal/', include('paypal.express.urls')),
    (r'', include(shop.urls)),
)
if settings.DEBUG:
    urlpatterns += staticfiles_urlpatterns()
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
    urlpatterns += patterns('',
        url(r'^404$', TemplateView.as_view(template_name='404.html')),
        url(r'^500$', TemplateView.as_view(template_name='500.html')),
    )


#!/usr/bin/env python
from django.core.management import execute_manager
try:
    import settings # Assumed to be in the same directory.
except ImportError:
    import sys
    sys.stderr.write("Error: Can't find the file 'settings.py' in the directory containing %r. It appears you've customized things.\nYou'll have to run django-admin.py, passing it your settings module.\n(If the file settings.py does indeed exist, it's causing an ImportError somehow.)\n" % __file__)
    sys.exit(1)

if __name__ == "__main__":
    try:
        execute_manager(settings)
    except Exception, e:
        # Custom handling of exceptions to make sure
        # that Sentry handles them.
        import sys, traceback
        if sys.stdout.isatty():
            traceback.print_exc()
        else:
            if settings.DEBUG or not 'sentry.client' in settings.INSTALLED_APPS:
                raise
            from sentry.client.models import get_client
            exc_info = sys.exc_info()
            if getattr(exc_info[0], 'skip_sentry', False):
                raise
            get_client().create_from_exception(exc_info)
            
            # Email admins
            import logging
            logger = logging.getLogger('management_commands')
            logger.exception(e)
